@@ -154,9 +154,8 @@ class ResourceManager(object):
         if not fields:
             raise ResourceNoFieldsProvidedError
 
-        if 'uploads' in fields:
-            for index, upload in enumerate(fields['uploads']):
-                fields['uploads'][index]['token'] = self.redmine.upload(upload.get('path', ''))
+        for index, upload in enumerate(fields.get('uploads', [])):
+            fields['uploads'][index]['token'] = self.redmine.upload(upload.get('path', ''))
 
         formatter = MemorizeFormatter()
 
@@ -195,6 +194,9 @@ class ResourceManager(object):
         if not fields:
             raise ResourceNoFieldsProvidedError
 
+        for index, upload in enumerate(fields.get('uploads', [])):
+            fields['uploads'][index]['token'] = self.redmine.upload(upload.get('path', ''))
+
         formatter = MemorizeFormatter()
 
         try:
